pub struct SolanaFunctionEnvironment {Show 13 fields
pub function_key: String,
pub payer: String,
pub verifier: String,
pub reward_receiver: String,
pub function_data: String,
pub verifier_enclave_signer: String,
pub queue_authority: String,
pub function_routine_key: String,
pub function_routine_data: String,
pub function_request_key: String,
pub function_request_data: String,
pub cluster: String,
pub minimum_context_slot: Option<u64>,
}client only.Expand description
The expected environment variables when a solana function is being executed
Fields
function_key: StringFUNCTION_KEY: the pubkey of the function being executed
payer: StringPAYER: The gas payer for this transaction
verifier: StringVERIFIER: the pubey of the oracle veriying this call
reward_receiver: StringREWARD_RECEIVER: The escrow to send the reward the oracle will receive for executing this function
function_data: StringFUNCTION_DATA: The preloaded data of the FUNCTION_KEY account
verifier_enclave_signer: StringVERIFIER_ENCLAVE_SIGNER: The keypair the verifying oracle is using to sign this transaction.
QUEUE_AUTHORITY: The authority of the oracle queue this function is executing on.
function_routine_key: StringFUNCTION_ROUTINE_KEY: If this function is being called with parameters, this variable will hold the pubkey of the request account
function_routine_data: StringFUNCTION_ROUTINE_DATA: The preloaded data of the FUNCTION_ROUTINE_KEY
account
function_request_key: StringFUNCTION_REQUEST_KEY: If this function is being called with parameters, this ariable will hold the pubkey of the request account
function_request_data: StringFUNCTION_REQUEST_DATA: The preloaded data of the FUNCTION_REQUEST_KEY
account
cluster: Stringminimum_context_slot: Option<u64>Implementations